@@ -13,7 +13,8 @@
 #    limitations under the License.
 
 import tkinter
-from tkmacosx.utils import (_cnfmerge, _bind, _Canvas, check_param,
+from tkmacosx.utils import (SYSTEM_DEFAULT_BG, SYSTEM_DEFAULT_FG, 
+                            _cnfmerge, _bind, _Canvas, check_param,
                             _info_button, _on_press_color, 
                             get_shade, check_function_equality)
 import tkmacosx.utils.colorvar_patches as cp
@@ -47,6 +48,8 @@ BUTTON_ITEMS = (
 
 BORDER_INTENSITY = 0.06
 
+_warning_msg_shown = [False]
+
 
 class _button_properties:
     """Internal class.\n
@@ -131,16 +134,29 @@ class _button_properties:
         return _button_properties._bit_img(self, 'bitmap', kw)
 
     def borderless(self, kw):
+        def _get_master_bg():
+            """Internal function."""
+            try: 
+                return self.master['bg']
+            except tkinter.TclError:
+                if not _warning_msg_shown[0]:
+                    print('WARNING: "borderless" option of '
+                        'tkmacosx Button doesn\'t work with ttk widgets. '
+                        'Bordercolor/highlightbackground can be set manually '
+                        'with "highlightbackground" or "bordercolor" options.\n')
+                    _warning_msg_shown[0] = True
+                return self.cnf.get('bordercolor', self.cnf['highlightbackground'])
+
         _opt = {}
         if bool(kw.get('borderless')) or self.cnf.get('borderless'):
             if not check_function_equality(self.master.config, self._get_functions('borderless', kw)):
                 self.master.config = self.master.configure = self._get_functions(
                     'borderless', kw)
-            self.cnf['highlightbackground'] = self.cnf['bordercolor'] = self.master['bg']
-            _opt[1] = [('itemconfigure', '_bd_color'), {'outline': self.master['bg']}, None]
-            _opt[2] = ['configure', {'highlightbackground': self.master['bg']}, None]
+            self.cnf['highlightbackground'] = self.cnf['bordercolor'] = _get_master_bg()
+            _opt[1] = [('itemconfigure', '_bd_color'), {'outline': _get_master_bg()}, None]
+            _opt[2] = ['configure', {'highlightbackground': _get_master_bg()}, None]
         elif not bool(kw.get('borderless', True)) or not self.cnf.get('borderless'):
-            if self.cnf.get('bordercolor') == self.master['bg']:
+            if self.cnf.get('bordercolor') == _get_master_bg():
                 self.cnf.pop('bordercolor', None)
                 self.cnf.pop('highlightbackground', None)
             bd_color = self.cnf.get(
@@ -990,7 +1006,7 @@ class ButtonBase(_Canvas, _button_functions):
             if i in BUTTON_FEATURES:
                 cnf[i] = kw.pop(i, None)
 
-        cnf['fg'] = cnf['foreground'] = cnf.get('fg', cnf.get('foreground', 'black'))
+        cnf['fg'] = cnf['foreground'] = cnf.get('fg', cnf.get('foreground', SYSTEM_DEFAULT_FG))
         cnf['anchor'] = cnf.get('anchor', 'center')
         cnf['justify'] = cnf.get('justify', 'center')
         cnf['borderless'] = cnf.get('borderless', False)
@@ -1023,7 +1039,7 @@ class ButtonBase(_Canvas, _button_functions):
             kw['height'] = kw.get('height', 24)
 
         kw['takefocus'] = kw.get('takefocus', 1)
-        kw['bg'] = kw.pop('bg', kw.pop('background', 'white'))
+        kw['bg'] = kw.pop('bg', kw.pop('background', SYSTEM_DEFAULT_BG))
         kw['highlightthickness'] = kw.get('highlightthickness', 0)
 
         _Canvas.__init__(self, master=master, **kw)
